"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stringify_1 = require("@code-engine/stringify");
const utils_1 = require("@code-engine/utils");
const ono_1 = require("ono");
const types_1 = require("./types");
/**
 * Normalizes any `PluginDefinition` value to a `Plugin` object.
 * @internal
 */
async function normalizePlugin(definition, workerPool, defaultName) {
    try {
        if (typeof definition === "function") {
            // This plugin is just a main-thread processFile() method
            definition = { name: definition.name, processFile: definition };
        }
        else if (types_1.isModuleDefinition(definition)) {
            // This plugin is just a worker-thread processFile() method
            definition = { processFile: definition };
        }
        else if (!types_1.isPlugin(definition)) {
            throw ono_1.ono.type(`Invalid CodeEngine plugin: ${stringify_1.stringify(definition)}`);
        }
        let name = definition.name;
        if (types_1.isModuleDefinition(definition.processFile)) {
            // Import the FileProcessor on all worker threads
            definition.processFile = await workerPool.importFileProcessor(definition.processFile);
            name = name || definition.processFile.name;
        }
        definition.name = String(name || defaultName);
        return definition;
    }
    catch (error) {
        throw utils_1.typedOno(error, `Error in ${defaultName}.`);
    }
}
exports.normalizePlugin = normalizePlugin;
//# sourceMappingURL=normalize-plugin.js.map